@@ -13,10 +13,6 @@ class Strings(Instrument):
 		wild = state['wild']
 		if state["tick"] % state["resolution"] == 0 and \
 				random() < 4.0 * wild:
-			self.params["let_ring"] = True
 			return NoteContainer(state["chord"])
-		else:
-			if state["tick"] == state["ticks"] - 1:
-				self.params["let_ring"] = False
-			return None
+		return None
 
