@@ -122,7 +122,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			lambda: self.swap_list_item(self.ui.progressions, False))
 		self.connect(self.ui.clearprogressions,
 			QtCore.SIGNAL("clicked()"),
-			self.ui.progressions.clear)
+			lambda: self.ui.progressions.clear() or self.progression_changed())
 		self.connect(self.ui.action_About,
 			QtCore.SIGNAL("activated()"),
 			self.show_about)
@@ -171,6 +171,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.importprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.import_progression)
+		
 
 
 	def set_defaults(self):
@@ -205,6 +206,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.ui.swing.setChecked(False)
 
 		self.set_title()
+		self.progression_changed()
 	
 	def add_block(self):
 		self.ui.blocks.addItem("Block")
@@ -221,16 +223,19 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.progressioncombo.currentText())
 		self.ui.progressions.setCurrentRow(int(self.ui.progressions.count()) - 1)
 		self.edit_progression()
+		self.progression_changed()
 
 	def remove_progression(self):
 		i = self.ui.progressions.currentRow()
 		if i >= 0:
 			self.ui.progressions.takeItem(i)
+		self.progression_changed()
 
 	def copy_progression(self):
 		i = self.ui.progressions.currentRow()
 		if i >= 0:
 			self.ui.progressions.addItem(self.ui.progressions.item(i).text())
+		self.progression_changed()
 
 	def import_progression(self):
 		h = "/home"
@@ -253,6 +258,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				fp.close()
 			except Options.OptionError, err:
 				self.set_status("Error: " + str(err))
+		self.progression_changed()
 
 
 	def export_progression(self):
@@ -277,6 +283,27 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				fp.close()
 			except IOError:
 				self.set_status("Error: Couldn't open file for writing")
+		self.progression_changed()
+
+	def progression_changed(self):
+		if self.ui.progressions.count() == 0:
+			self.enable_progression(False)
+		else:
+			self.enable_progression(True)
+		
+
+	def enable_progression(self, enable = True):
+		self.ui.exportprogressions.setEnabled(enable)
+		self.ui.upprogression.setEnabled(False)
+		self.ui.downprogression.setEnabled(False)
+		self.ui.clearprogressions.setEnabled(enable)
+		self.ui.copyprogression.setEnabled(enable)
+		self.ui.editprogression.setEnabled(enable)
+		self.ui.removeprogression.setEnabled(enable)
+
+		if enable and self.ui.progressions.count() > 1:
+			self.ui.upprogression.setEnabled(enable)
+			self.ui.downprogression.setEnabled(enable)
 
 	def add_instrument(self):
 		self.ui.instruments.addItem(self.ui.instrumentcombo.currentText())
